@@ -23,7 +23,7 @@ from aliyunsdkr_kvstore.endpoint import endpoint_data
 class DescribeAvailableResourceRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'R-kvstore', '2015-01-01', 'DescribeAvailableResource')
+		RpcRequest.__init__(self, 'R-kvstore', '2015-01-01', 'DescribeAvailableResource','redisa')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
@@ -60,12 +60,6 @@ class DescribeAvailableResourceRequest(RpcRequest):
 	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
 		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
 
-	def get_Level(self):
-		return self.get_query_params().get('Level')
-
-	def set_Level(self,Level):
-		self.add_query_param('Level',Level)
-
 	def get_OwnerAccount(self):
 		return self.get_query_params().get('OwnerAccount')
 
@@ -82,10 +76,4 @@ class DescribeAvailableResourceRequest(RpcRequest):
 		return self.get_query_params().get('ZoneId')
 
 	def set_ZoneId(self,ZoneId):
-		self.add_query_param('ZoneId',ZoneId)
-
-	def get_OrderType(self):
-		return self.get_query_params().get('OrderType')
-
-	def set_OrderType(self,OrderType):
-		self.add_query_param('OrderType',OrderType)
\ No newline at end of file
+		self.add_query_param('ZoneId',ZoneId)
\ No newline at end of file
